/*****************************************************************************
 *
 * Multitouch research project
 *
 * Copyright (C) 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ****************************************************************************/

#ifndef DEVICE_H_
#define DEVICE_H_

#include<vector>
#include"Frame.h"

class Device {
private:

    int id;
    std::vector<Frame> frames;

    // Device properties here.

    bool is_new_frame_valid(const Frame &new_frame);
    bool check_validity_forward(const Frame &new_frame, const std::vector<Touch> &old_touches);
    bool check_validity_backward(const Frame &old_frame, const std::vector<Touch> &new_touches);

public:
    Device();
    Device(int id_);
    ~Device();

    size_t num_frames() { return frames.size(); }
    const std::vector<Frame>& get_frames() { return frames; }

    void add_frame(const Frame &f);
    void pop_oldest_frame();
    int get_id() const { return id; }
    void clear_frames() { frames.clear(); }
};

#endif /* DEVICE_H_ */
