/*****************************************************************************
 *
 * Multitouch research project
 *
 * Copyright (C) 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ****************************************************************************/

#ifndef TOUCH_H_
#define TOUCH_H_

enum TouchState {
    TouchBegin,
    TouchUpdate,
    TouchEnd,
    TouchUnknown
};

const char* state_to_string(const TouchState state);

#define INVALID_TOUCH_ID -1

class Touch {

private:
    int id;
    double x, y;
    double timestamp;
    double angle, minor, major;
    TouchState state;

    static const Touch invalid_touch;

public:
    Touch();
    Touch(int id_, double x_, double y_, double timestamp_, double angle_, double minor_, double major_, TouchState state_);
    ~Touch();

    int get_id() const { return id; }
    double get_x() const { return x; }
    double get_y() const { return y; }
    TouchState get_state() const { return state; }

    bool is_invalid() const { return id == INVALID_TOUCH_ID && state == TouchUnknown; }
    static const Touch& get_invalid_touch() { return invalid_touch; }
};

#endif /* TOUCH_H_ */
